#[non_exhaustive]pub enum Error {
NoBinary,
BinaryIo(&'static str, Error),
BinaryStatus(&'static str, i32),
NoUtf8(FromUtf8Error),
}Expand description
Represents X11 binary related error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoBinary
The xclip or xsel binary could not be found on the system, required for clipboard support.
BinaryIo(&'static str, Error)
An error occurred while using xclip or xsel to manage the clipboard contents.
This problem probably occurred when starting, or while piping the clipboard contents
from/to the process.
BinaryStatus(&'static str, i32)
xclip or xsel unexpectetly exited with a non-successful status code.
NoUtf8(FromUtf8Error)
The clipboard contents could not be parsed as valid UTF-8.